#[derive(DefaultNew)]Expand description
Generates a Default impl for the given struct that just calls Self::new().
Specifically:
impl Default for Foo {
#[inline]
fn default() -> Self {
Self::new()
}
}#[derive(DefaultNew)]Generates a Default impl for the given struct that just calls Self::new().
Specifically:
impl Default for Foo {
#[inline]
fn default() -> Self {
Self::new()
}
}